#!/usr/bin/perl
# -------------------------------------------------------------
# SMSPreGnokii-delete
# -------------------------------------------------------------
# 0.01, 09/04/2000
# -------------------------------------------------------------
#
# Preprocessor for the gnokii command line utility to delete
# a message in the phone memory.
# Andres Seco Hernandez.
# AndresSH@ctv.es
# Guadalajara, Spain, April 2000.
#
# -------------------------------------------------------------

# -------------------------------------------------------------
# Functions
# -------------------------------------------------------------

sub read_conf_file {
# Look for second parameter line into first parameter file.
  my ($file,$word) = @_;
  $answer = "0";
  open (OPTIONS,"<$file");
  while (<OPTIONS>) {
    $record=$_;
    chop ($record);
    @field = split (/\t+/,$record);
    $answer = $field[1] if ( lc($field[0]) eq $word );
  }
  close (OPTIONS);
  return $answer;
}

sub send_log_file {
# Write message to log file depending on loglevel from config file.
# loglevel 1 = Log start and stop messages.
# loglevel 2 = Log start, stop and error messages.
# loglevel 3 = Log start, stop, error and warning messages.
# loglevel 4 = Log start, stop, error, warning and trace messages.
# loglevel 5 = Log start, stop, error, warning, trace and var.trace messages.
  my ($file,$message,$runningll,$messagell) = @_;
  if ( $runningll >= $messagell ) {
    open (LOGF,">>$file");
    print LOGF "SMSPreGnokii-delete: ".localtime(time())." ".$message."\n";
    close (LOGF);
  }
}

my ($MessageID) = @ARGV;

# -------------------------------------------------------------
# Global vars
# -------------------------------------------------------------

$conf_file = "SMSPreGnokii.conf";

# -------------------------------------------------------------
# Main code
# -------------------------------------------------------------

#---- Starting ----
$conf_logfile = read_conf_file($conf_file,"logfile");
$conf_loglevel = read_conf_file($conf_file,"loglevel");
send_log_file($conf_logfile,"SMSPreGnokii v0.01, Preprocessor for the gnokii command line utility.",$conf_loglevel,1);
send_log_file($conf_logfile,"Andres Seco, AndresSH\@ctv.es",$conf_loglevel,1);
send_log_file($conf_logfile,"Starting...",$conf_loglevel,1);
$conf_gnokiipath = read_conf_file($conf_file,"gnokiipath");
$conf_gnokiireadsms = read_conf_file($conf_file,"gnokiireadsms");
$conf_gnokiideletesms = read_conf_file($conf_file,"gnokiideletesms");
send_log_file($conf_logfile,"MessageID=".$MessageID,$conf_loglevel,5);
send_log_file($conf_logfile,"gnokiipath=".$conf_gnokiipath,$conf_loglevel,5);
send_log_file($conf_logfile,"gnokiireadsms=".$conf_gnokiireadsms,$conf_loglevel,5);
send_log_file($conf_logfile,"gnokiideletesms=".$conf_gnokiideletesms,$conf_loglevel,5);

#---- Getting message in the phone ----
$conf_gnokiireadsms =~ s/%MessageNumber%/$MessageID/g;
send_log_file($conf_logfile,"Substitution of MessageNumber in read=".$conf_gnokiireadsms,$conf_loglevel,5);
@answer = qx { $conf_gnokiipath $conf_gnokiireadsms 2>/dev/null };
$counter = 0;
for (@answer) {
  send_log_file($conf_logfile,"Into loop. Counter=".$counter,$conf_loglevel,4);
  $record = $_;
  chop ($record);
  if ( $record =~ /([0-9]*). Inbox Message/ ) {
    send_log_file($conf_logfile,"Found - Inbox Message",$conf_loglevel,4);
    $table[$counter][0] = $1;
    $counter++;
  }
  if ( $record =~ /Date\/time: ([0-9\/: GMT+-h]*)/ ) {
    send_log_file($conf_logfile,"Found - Date Time",$conf_loglevel,4);
    $table[$counter-1][1] = $1;
  }
  if ( $record =~ /Sender: ([0-9+]*) Msg Center: ([0-9+]*)/ ) {
    send_log_file($conf_logfile,"Found - Sender Msg Center",$conf_loglevel,4);
    $table[$counter-1][2] = $1;
    $table[$counter-1][3] = $2;
  }
  if ( $record =~ /Text: / ) {
    send_log_file($conf_logfile,"Found - Text",$conf_loglevel,4);
    $table[$counter-1][4] = substr($record,6);
  }
}
if ( $counter eq 0 ) {
  send_log_file($conf_logfile,"NO MESSAGE",$conf_loglevel,3);
  printf "NO MESSAGE\n";
} else {
  if ( $counter eq 1 ) {
    print "MessageID: ".$table[0][0]."\n";
    print "Date: ".$table[0][1]."\n";
    print "From: ".$table[0][2]."\n";
    print "SMSC: ".$table[0][3]."\n";
    print "Content: ".$table[0][4]."\n";
    $conf_gnokiideletesms =~ s/%MessageNumber%/$MessageID/g;
    send_log_file($conf_logfile,"Substitution of MessageNumber in delete=".$conf_gnokiideletesms,$conf_loglevel,5);
    $answer = qx { $conf_gnokiipath $conf_gnokiideletesms 2>/dev/null };
    send_log_file($conf_logfile,"Answer from Gnokii=".$answer,$conf_loglevel,5);
  } else {
    send_log_file($conf_logfile,"ERROR",$conf_loglevel,2);
    printf "ERROR\n";
  }
}

#---- Ending ----
send_log_file($conf_logfile,"Ending...",$conf_loglevel,1);

