#!/usr/bin/perl
# -------------------------------------------------------------
# SMSPreGnokii-read
# -------------------------------------------------------------
# 0.01, 09/04/2000
# -------------------------------------------------------------
#
# Preprocessor for the gnokii command line utility to read the
# next message in the phone memory.
# Andres Seco Hernandez.
# AndresSH@ctv.es
# Guadalajara, Spain, April 2000.
#
# -------------------------------------------------------------

# -------------------------------------------------------------
# Functions
# -------------------------------------------------------------

sub read_conf_file {
# Look for second parameter line into first parameter file.
  my ($file,$word) = @_;
  $answer = "0";
  open (OPTIONS,"<$file");
  while (<OPTIONS>) {
    $record=$_;
    chop ($record);
    @field = split (/\t+/,$record);
    $answer = $field[1] if ( lc($field[0]) eq $word );
  }
  close (OPTIONS);
  return $answer;
}

sub send_log_file {
# Write message to log file depending on loglevel from config file.
# loglevel 1 = Log start and stop messages.
# loglevel 2 = Log start, stop and error messages.
# loglevel 3 = Log start, stop, error and warning messages.
# loglevel 4 = Log start, stop, error, warning and trace messages.
# loglevel 5 = Log start, stop, error, warning, trace and var.trace messages.
  my ($file,$message,$runningll,$messagell) = @_;
  if ( $runningll >= $messagell ) {
    open (LOGF,">>$file");
    print LOGF "SMSPreGnokii-read: ".localtime(time())." ".$message."\n";
    close (LOGF);
  }
}

sub prepare_date {
# Change format of date and time to compare it.
  my ($input) = @_;
  @parts_total = split (/ /,$input);
  @parts_date = split (/\//,$parts_total[0]);
  @parts_time = split (/:/,$parts_total[1]);
  if ( $parts_date[2] gt 50 ) {
    $answer = "19";
  } else {
    $answer = "20";
  }
  if ( length($parts_date[2]) eq 1 ) {
    $answer = $answer."0";
  }
  $answer = $answer.$parts_date[2];
  if ( length($parts_date[1]) eq 1 ) {
    $answer = $answer."0";
  }
  $answer = $answer.$parts_date[1];
  if ( length($parts_date[0]) eq 1 ) {
    $answer = $answer."0";
  }
  $answer = $answer.$parts_date[0];
  if ( length($parts_time[0]) eq 1 ) {
    $answer = $answer."0";
  }
  $answer = $answer.$parts_time[0];
  if ( length($parts_time[1]) eq 1 ) {
    $answer = $answer."0";
  }
  $answer = $answer.$parts_time[1];
  if ( length($parts_time[2]) eq 1 ) {
    $answer = $answer."0";
  }
  $answer = $answer.$parts_time[2];
  return $answer;
}

# -------------------------------------------------------------
# Global vars
# -------------------------------------------------------------

$conf_file = "SMSPreGnokii.conf";

# -------------------------------------------------------------
# Main code
# -------------------------------------------------------------

#---- Starting ----
$conf_logfile = read_conf_file($conf_file,"logfile");
$conf_loglevel = read_conf_file($conf_file,"loglevel");
send_log_file($conf_logfile,"SMSPreGnokii v0.01, Preprocessor for the gnokii command line utility.",$conf_loglevel,1);
send_log_file($conf_logfile,"Andres Seco, AndresSH\@ctv.es",$conf_loglevel,1);
send_log_file($conf_logfile,"Starting...",$conf_loglevel,1);
$conf_gnokiipath = read_conf_file($conf_file,"gnokiipath");
$conf_gnokiireadallsms = read_conf_file($conf_file,"gnokiireadallsms");
$conf_gnokiireadsms = read_conf_file($conf_file,"gnokiireadsms");
send_log_file($conf_logfile,"gnokiipath=".$conf_gnokiipath,$conf_loglevel,5);
send_log_file($conf_logfile,"gnokiireadallsms=".$conf_gnokiireadallsms,$conf_loglevel,5);
send_log_file($conf_logfile,"gnokiireadsms=".$conf_gnokiireadsms,$conf_loglevel,5);

#---- Getting all messages in the phone ----
@answer = qx { $conf_gnokiipath $conf_gnokiireadallsms 2>/dev/null };
$counter = 0;
for (@answer) {
  send_log_file($conf_logfile,"Into loop. Counter=".$counter,$conf_loglevel,4);
  $record = $_;
  chop ($record);
  if ( $record =~ /([0-9]*). Inbox Message/ ) {
    send_log_file($conf_logfile,"Found - Inbox Message",$conf_loglevel,4);
    $table[$counter][0] = $1;
    $counter++;
  }
  if ( $record =~ /Date\/time: ([0-9\/: GMT+-h]*)/ ) {
    send_log_file($conf_logfile,"Found - Date Time",$conf_loglevel,4);
    $table[$counter-1][1] = $1;
  }
  if ( $record =~ /Sender: ([0-9+]*) Msg Center: ([0-9+]*)/ ) {
    send_log_file($conf_logfile,"Found - Sender Msg Center",$conf_loglevel,4);
    $table[$counter-1][2] = $1;
    $table[$counter-1][3] = $2;
  }
  if ( $record =~ /Text: / ) {
    send_log_file($conf_logfile,"Found - Text",$conf_loglevel,4);
    $table[$counter-1][4] = substr($record,6);
  }
}
if ( $counter eq 0 ) {
  send_log_file($conf_logfile,"NO MESSAGE",$conf_loglevel,3);
  printf "NO MESSAGE\n";
} else {
  send_log_file($conf_logfile,"There are messages. Counter=".$counter,$conf_loglevel,4);
#---- Selecting oldest
  $oldest_index = -1;
  for ($i = 0; $i < $counter; $i++) {
    send_log_file($conf_logfile,"Message ".$table[$i][0]." ".$table[$i][1]." ".$table[$i][2]." ".$table[$i][3],$conf_loglevel,5);
    if ( $oldest_index eq -1 ) {
      send_log_file($conf_logfile,"First message in the queue=".$table[$i][0],$conf_loglevel,4);
      $oldest_index = $i;
      $oldest_date = $table[$i][1];
    } else {
      $cmp1 = prepare_date($oldest_date);
      $cmp2 = prepare_date($table[$i][1]);
      send_log_file($conf_logfile,"cmp1=".$cmp1,$conf_loglevel,5);
      send_log_file($conf_logfile,"cmp2=".$cmp2,$conf_loglevel,5);
      if ( $cmp1 gt $cmp2 ) {
        send_log_file($conf_logfile,"Message ".$table[$i][0]." before ".$table[$oldest_index][0].". Changing oldest_index.",$conf_loglevel,4);
        $oldest_index = $i;
        $oldest_date = $table[$i][1];
      } else {
        send_log_file($conf_logfile,"Message ".$table[$i][0]." after ".$table[$oldest_index][0].". No change in oldest_index.",$conf_loglevel,4);
      }
    }
  }
  print "MessageID: ".$table[$oldest_index][0]."\n";
  print "Date: ".$table[$oldest_index][1]."\n";
  print "From: ".$table[$oldest_index][2]."\n";
  print "SMSC: ".$table[$oldest_index][3]."\n";
  print "Content: ".$table[$oldest_index][4]."\n";
}

#---- Ending ----
send_log_file($conf_logfile,"Ending...",$conf_loglevel,1);

